Stan Math Library: stan::math::op_dv_vari Class Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Protected Attributes | List of all members
stan::math::op_dv_vari Class Reference

`#include <dv_vari.hpp>`

Inheritance diagram for stan::math::op_dv_vari:

## Public Member Functions
| op_dv_vari (double f, double a, vari *bvi)
Public Member Functions inherited from stan::math::vari
| vari (const double x)
| Construct a variable implementation from a value. More...
| vari (const double x, bool stacked)
virtual | ~vari ()
| Throw an illegal argument exception. More...
virtual void | chain ()
| Apply the chain rule to this variable based on the variables on which it depends. More...
void | init_dependent ()
| Initialize the adjoint for this (dependent) variable to 1. More...
void | set_zero_adjoint ()
| Set the adjoint value of this variable to 0. More...

## Protected Attributes
double | ad_
vari * | bvi_

## Additional Inherited Members
Static Public Member Functions inherited from stan::math::vari
static void * | operator new (size_t nbytes)
| Allocate memory from the underlying memory pool. More...
static void | operator delete (void *)
| Delete a pointer from the underlying memory pool. More...
Public Attributes inherited from stan::math::vari
const double | val_
| The value of this variable. More...
double | adj_
| The adjoint of this variable, which is the partial derivative of this variable with respect to the root variable. More...

## Detailed Description

Definition at line 9 of file dv_vari.hpp.

## Constructor & Destructor Documentation

stan::math::op_dv_vari::op_dv_vari | ( | double | f,
|  | double | a,
|  | vari * | bvi
| ) |  |
| inline

Definition at line 14 of file dv_vari.hpp.

## Member Data Documentation

double stan::math::op_dv_vari::ad_
| protected

Definition at line 11 of file dv_vari.hpp.

vari* stan::math::op_dv_vari::bvi_
| protected

Definition at line 12 of file dv_vari.hpp.

The documentation for this class was generated from the following file:

- stan/math/rev/core/dv_vari.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.